==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebGridDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
import { WebColumnDescriptionModule } from "./WebColumnDescriptionModule";
import { WebGridToolbarDescriptionModule } from "./WebGridToolbarDescriptionModule";
import { WebGridToolbarActionsDescriptionModule } from "./WebGridToolbarActionsDescriptionModule";
import { WebGridToolbarTitleDescriptionModule } from "./WebGridToolbarTitleDescriptionModule";
import { WebGridToolbarAdvancedFilteringDescriptionModule } from "./WebGridToolbarAdvancedFilteringDescriptionModule";
import { WebGridToolbarExporterDescriptionModule } from "./WebGridToolbarExporterDescriptionModule";
import { WebGridToolbarHidingDescriptionModule } from "./WebGridToolbarHidingDescriptionModule";
import { WebGridToolbarPinningDescriptionModule } from "./WebGridToolbarPinningDescriptionModule";
import { WebActionStripDescriptionModule } from "./WebActionStripDescriptionModule";
import { WebGridActionsBaseDirectiveDescriptionModule } from "./WebGridActionsBaseDirectiveDescriptionModule";
import { WebGridEditingActionsDescriptionModule } from "./WebGridEditingActionsDescriptionModule";
import { WebGridPinningActionsDescriptionModule } from "./WebGridPinningActionsDescriptionModule";
import { WebGridDescriptionMetadata } from "./WebGridDescriptionMetadata";
/**
 * @hidden
 */
var WebGridDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridDescriptionModule, _super);
    function WebGridDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridDescriptionModule.register = function (a) {
        WebColumnDescriptionModule.register(a);
        WebGridToolbarDescriptionModule.register(a);
        WebGridToolbarActionsDescriptionModule.register(a);
        WebGridToolbarTitleDescriptionModule.register(a);
        WebGridToolbarAdvancedFilteringDescriptionModule.register(a);
        WebGridToolbarExporterDescriptionModule.register(a);
        WebGridToolbarHidingDescriptionModule.register(a);
        WebGridToolbarPinningDescriptionModule.register(a);
        WebActionStripDescriptionModule.register(a);
        WebGridActionsBaseDirectiveDescriptionModule.register(a);
        WebGridEditingActionsDescriptionModule.register(a);
        WebGridPinningActionsDescriptionModule.register(a);
        WebGridDescriptionMetadata.d(a);
    };
    WebGridDescriptionModule.$t = markType(WebGridDescriptionModule, 'WebGridDescriptionModule');
    return WebGridDescriptionModule;
}(Base));
export { WebGridDescriptionModule };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebGridDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { WebColumnDescriptionModule } from "./WebColumnDescriptionModule";
import { WebGridToolbarDescriptionModule } from "./WebGridToolbarDescriptionModule";
import { WebGridToolbarActionsDescriptionModule } from "./WebGridToolbarActionsDescriptionModule";
import { WebGridToolbarTitleDescriptionModule } from "./WebGridToolbarTitleDescriptionModule";
import { WebGridToolbarAdvancedFilteringDescriptionModule } from "./WebGridToolbarAdvancedFilteringDescriptionModule";
import { WebGridToolbarExporterDescriptionModule } from "./WebGridToolbarExporterDescriptionModule";
import { WebGridToolbarHidingDescriptionModule } from "./WebGridToolbarHidingDescriptionModule";
import { WebGridToolbarPinningDescriptionModule } from "./WebGridToolbarPinningDescriptionModule";
import { WebActionStripDescriptionModule } from "./WebActionStripDescriptionModule";
import { WebGridActionsBaseDirectiveDescriptionModule } from "./WebGridActionsBaseDirectiveDescriptionModule";
import { WebGridEditingActionsDescriptionModule } from "./WebGridEditingActionsDescriptionModule";
import { WebGridPinningActionsDescriptionModule } from "./WebGridPinningActionsDescriptionModule";
import { WebForOfStateEventArgsDescriptionMetadata } from "./WebForOfStateEventArgsDescriptionMetadata";
import { WebGroupingDoneEventArgsDescriptionMetadata } from "./WebGroupingDoneEventArgsDescriptionMetadata";
import { WebGridMasterDetailContextDescriptionMetadata } from "./WebGridMasterDetailContextDescriptionMetadata";
import { WebGroupByRowSelectorTemplateContextDescriptionMetadata } from "./WebGroupByRowSelectorTemplateContextDescriptionMetadata";
import { WebGroupByRowTemplateContextDescriptionMetadata } from "./WebGroupByRowTemplateContextDescriptionMetadata";
import { WebGridDescriptionMetadata } from "./WebGridDescriptionMetadata";
import { TemplateContainerDescriptionModule } from "./TemplateContainerDescriptionModule";
import { ChildContentDescriptionModule } from "./ChildContentDescriptionModule";
/**
 * @hidden
 */
var WebGridDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridDescriptionModule, _super);
    function WebGridDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridDescriptionModule.register = function (a) {
        WebColumnDescriptionModule.register(a);
        WebGridToolbarDescriptionModule.register(a);
        WebGridToolbarActionsDescriptionModule.register(a);
        WebGridToolbarTitleDescriptionModule.register(a);
        WebGridToolbarAdvancedFilteringDescriptionModule.register(a);
        WebGridToolbarExporterDescriptionModule.register(a);
        WebGridToolbarHidingDescriptionModule.register(a);
        WebGridToolbarPinningDescriptionModule.register(a);
        WebActionStripDescriptionModule.register(a);
        WebGridActionsBaseDirectiveDescriptionModule.register(a);
        WebGridEditingActionsDescriptionModule.register(a);
        WebGridPinningActionsDescriptionModule.register(a);
        WebForOfStateEventArgsDescriptionMetadata.d(a);
        WebGroupingDoneEventArgsDescriptionMetadata.d(a);
        WebGridMasterDetailContextDescriptionMetadata.d(a);
        WebGroupByRowSelectorTemplateContextDescriptionMetadata.d(a);
        WebGroupByRowTemplateContextDescriptionMetadata.d(a);
        WebGridDescriptionMetadata.d(a);
        TemplateContainerDescriptionModule.register(a);
        ChildContentDescriptionModule.register(a);
    };
    WebGridDescriptionModule.$t = markType(WebGridDescriptionModule, 'WebGridDescriptionModule');
    return WebGridDescriptionModule;
}(Base));
export { WebGridDescriptionModule };
